@@ -34,20 +34,23 @@ class Pollution(BaseComponent):
     def __init__(
         self,
         nlp: Language,
-        pollution: Optional[Dict[str, Union[str, List[str]]]],
+        pollution: Optional[Dict[str, Union[bool, str, List[str]]]],
     ):
 
         self.nlp = nlp
         self.nlp.vocab.strings.add("EXCLUDED")
 
         if pollution is None:
-            pollution = patterns.pollution
+            pollution = {k: True for k in patterns.pollution.keys()}
+        self.pollution = dict()
 
-        self.pollution = pollution
-
-        for k, v in self.pollution.items():
-            if isinstance(v, str):
+        for k, v in pollution.items():
+            if v is True:
+                self.pollution[k] = [patterns.pollution[k]]
+            elif isinstance(v, str):
                 self.pollution[k] = [v]
+            elif isinstance(v, list):
+                self.pollution[k] = v
 
         self.regex_matcher = RegexMatcher()
         self.build_patterns()
