@@ -13,8 +13,17 @@ DEFAULT_CONFIG = dict(
 )
 
 
-@deprecated_factory("sentences", "eds.sentences", default_config=DEFAULT_CONFIG)
-@Language.factory("eds.sentences", default_config=DEFAULT_CONFIG)
+@deprecated_factory(
+    "sentences",
+    "eds.sentences",
+    default_config=DEFAULT_CONFIG,
+    assigns=["token.is_sent_start"],
+)
+@Language.factory(
+    "eds.sentences",
+    default_config=DEFAULT_CONFIG,
+    assigns=["token.is_sent_start"],
+)
 def create_component(
     nlp: Language,
     name: str,
