@@ -15,6 +15,7 @@ from .misc.dates.factory import create_component as dates
 from .misc.measurements.factory import create_component as measurements
 from .misc.reason.factory import create_component as reason
 from .misc.sections.factory import create_component as sections
+from .ner.adicap.factory import create_component as adicap
 from .ner.cim10.factory import create_component as cim10
 from .ner.covid.factory import create_component as covid
 from .ner.drugs.factory import create_component as drugs
@@ -30,3 +31,4 @@ from .qualifiers.history.factory import create_component as history
 from .qualifiers.hypothesis.factory import create_component as hypothesis
 from .qualifiers.negation.factory import create_component as negation
 from .qualifiers.reported_speech.factory import create_component as rspeech
+from .trainable.nested_ner import create_component as nested_ner
