@@ -106,8 +106,8 @@ class ConsultationDates(GenericMatcher):
 
         self.set_extensions()
 
-    @staticmethod
-    def set_extensions() -> None:
+    @classmethod
+    def set_extensions(cls) -> None:
         if not Span.has_extension("consultation_date"):
             Span.set_extension("consultation_date", default=None)
 
