@@ -78,8 +78,12 @@ class Sections(GenericMatcher):
 
         self.add_patterns = add_patterns
         if add_patterns:
+
             for k, v in sections.items():
-                sections[k] = [r"\n[^\n]{0,5}" + ent + r"[^\n]{0,5}\n" for ent in v]
+
+                sections[k] = [
+                    r"(?<=(?:\n|^)[^\n]{0,5})" + ent + r"(?=[^\n]{0,5}\n)" for ent in v
+                ]
 
         super().__init__(
             nlp,
@@ -94,8 +98,8 @@ class Sections(GenericMatcher):
         if not nlp.has_pipe("normalizer") and not not nlp.has_pipe("eds.normalizer"):
             logger.warning("You should add pipe `eds.normalizer`")
 
-    @staticmethod
-    def set_extensions():
+    @classmethod
+    def set_extensions(cls):
 
         if not Span.has_extension("section_title"):
             Span.set_extension("section_title", default=None)
@@ -103,6 +107,12 @@ class Sections(GenericMatcher):
         if not Span.has_extension("section"):
             Span.set_extension("section", default=None)
 
+    @classmethod
+    def tag_ents(cls, sections: List[Span]):
+        for section in sections:
+            for e in section.ents:
+                e._.section = section.label_
+
     # noinspection PyProtectedMember
     def __call__(self, doc: Doc) -> Doc:
         """
@@ -120,13 +130,6 @@ class Sections(GenericMatcher):
         """
         titles = filter_spans(self.process(doc))
 
-        if self.add_patterns:
-            # Remove preceding newline
-            titles = [
-                Span(doc, title.start + 1, title.end - 1, label=title.label_)
-                for title in titles
-            ]
-
         sections = []
 
         for t1, t2 in zip(titles[:-1], titles[1:]):
@@ -143,4 +146,5 @@ class Sections(GenericMatcher):
         doc.spans["sections"] = sections
         doc.spans["section_titles"] = titles
 
+        self.tag_ents(sections)
         return doc
