@@ -5,7 +5,6 @@ from spacy import registry
 from spacy.language import Language
 from spacy.tokens import Doc, Span
 
-from edsnlp.matchers.utils import get_text
 from edsnlp.pipelines.core.contextual_matcher import ContextualMatcher
 from edsnlp.utils.filter import filter_spans
 
@@ -24,10 +23,10 @@ class Score(ContextualMatcher):
         A list of regexes to identify the score
     attr : str
         Wether to match on the text ('TEXT') or on the normalized text ('NORM')
-    after_extract : str
+    value_extract : str
         Regex with capturing group to get the score value
     score_normalization : Callable[[Union[str,None]], Any]
-        Function that takes the "raw" value extracted from the `after_extract` regex,
+        Function that takes the "raw" value extracted from the `value_extract` regex,
         and should return
         - None if no score could be extracted
         - The desired score value else
@@ -42,43 +41,51 @@ class Score(ContextualMatcher):
         score_name: str,
         regex: List[str],
         attr: str,
-        after_extract: Union[str, Dict[str, str], List[Dict[str, str]]],
+        value_extract: Union[str, Dict[str, str], List[Dict[str, str]]],
         score_normalization: Union[str, Callable[[Union[str, None]], Any]],
         window: int,
         ignore_excluded: bool,
         flags: Union[re.RegexFlag, int],
     ):
-        if isinstance(after_extract, str):
-            after_extract = [
+        if isinstance(value_extract, str):
+            value_extract = [
                 dict(
                     name="value",
-                    regex=after_extract,
+                    regex=value_extract,
                     window=window,
                 )
             ]
 
-        if isinstance(after_extract, dict):
-            after_extract = [after_extract]
+        if isinstance(value_extract, dict):
+            value_extract = [value_extract]
 
-        for i, extract in enumerate(after_extract):
+        value_exists = False
+        for i, extract in enumerate(value_extract):
             extract["window"] = extract.get("window", window)
-            after_extract[i] = extract
+            if extract.get("name", None) == "value":
+                value_exists = True
+                extract["replace_entity"] = True
+                extract["reduce_mode"] = "keep_first"
+            value_extract[i] = extract
+
+        assert value_exists, "You should provide a `value` regex in the `assign` dict."
 
         patterns = dict(
             source=score_name,
             regex=regex,
-            assign=after_extract,
+            assign=value_extract,
         )
 
         super().__init__(
             nlp=nlp,
             name=score_name,
             patterns=patterns,
-            assign_as_span=True,
+            assign_as_span=False,
             alignment_mode="expand",
             ignore_excluded=ignore_excluded,
             attr=attr,
             regex_flags=flags,
+            include_assigned=False,
         )
 
         self.score_name = score_name
@@ -90,8 +97,8 @@ class Score(ContextualMatcher):
 
         self.set_extensions()
 
-    @staticmethod
-    def set_extensions() -> None:
+    @classmethod
+    def set_extensions(cls) -> None:
         super(Score, Score).set_extensions()
         if not Span.has_extension("score_name"):
             Span.set_extension("score_name", default=None)
@@ -116,7 +123,9 @@ class Score(ContextualMatcher):
         ents = self.process(doc)
         ents = self.score_filtering(ents)
 
-        ents, discarded = filter_spans(list(doc.ents) + ents, return_discarded=True)
+        ents, discarded = filter_spans(
+            list(doc.ents) + list(ents), return_discarded=True
+        )
 
         doc.ents = ents
 
@@ -141,20 +150,14 @@ class Score(ContextualMatcher):
         ents: List[Span]
             List of spaCy's spans, with, if found, an added `score_value` extension
         """
-        to_keep_ents = []
+
         for ent in ents:
             value = ent._.assigned.get("value", None)
             if value is None:
                 continue
-            text_value = get_text(
-                value,
-                self.attr,
-                self.ignore_excluded,
-            )
-            normalized_value = self.score_normalization(text_value)
+            normalized_value = self.score_normalization(value)
             if normalized_value is not None:
-                value._.score_name = self.score_name
-                value._.score_value = normalized_value
-                to_keep_ents.append(value)
+                ent._.score_name = self.score_name
+                ent._.score_value = normalized_value
 
-        return to_keep_ents
+                yield ent
