@@ -9,7 +9,7 @@ from edsnlp.utils.deprecation import deprecated_factory
 
 DEFAULT_CONFIG = dict(
     regex=patterns.regex,
-    after_extract=patterns.after_extract,
+    value_extract=patterns.value_extract,
     score_normalization=patterns.score_normalization_str,
     attr="NORM",
     window=7,
@@ -18,13 +18,22 @@ DEFAULT_CONFIG = dict(
 )
 
 
-@deprecated_factory("charlson", "eds.charlson", default_config=DEFAULT_CONFIG)
-@Language.factory("eds.charlson", default_config=DEFAULT_CONFIG)
+@deprecated_factory(
+    "charlson",
+    "eds.charlson",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
+)
+@Language.factory(
+    "eds.charlson",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
+)
 def create_component(
     nlp: Language,
     name: str,
     regex: List[str],
-    after_extract: str,
+    value_extract: str,
     score_normalization: Union[str, Callable[[Union[str, None]], Any]],
     attr: str,
     window: int,
@@ -35,7 +44,7 @@ def create_component(
         nlp,
         score_name=name,
         regex=regex,
-        after_extract=after_extract,
+        value_extract=value_extract,
         score_normalization=score_normalization,
         attr=attr,
         window=window,
