@@ -9,24 +9,31 @@ from edsnlp.utils.deprecation import deprecated_factory
 
 DEFAULT_CONFIG = dict(
     regex=patterns.regex,
-    after_extract=patterns.after_extract,
+    value_extract=patterns.value_extract,
     score_normalization=patterns.score_normalization_str,
     attr="NORM",
     window=20,
     ignore_excluded=False,
-    flags=re.S,
+    flags=0,
 )
 
 
 @deprecated_factory(
-    "emergency.gemsa", "eds.emergency.gemsa", default_config=DEFAULT_CONFIG
+    "emergency.gemsa",
+    "eds.emergency.gemsa",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
+)
+@Language.factory(
+    "eds.emergency.gemsa",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
 )
-@Language.factory("eds.emergency.gemsa", default_config=DEFAULT_CONFIG)
 def create_component(
     nlp: Language,
     name: str,
     regex: List[str],
-    after_extract: str,
+    value_extract: str,
     score_normalization: Union[str, Callable[[Union[str, None]], Any]],
     attr: str,
     window: int,
@@ -37,7 +44,7 @@ def create_component(
         nlp,
         score_name=name,
         regex=regex,
-        after_extract=after_extract,
+        value_extract=value_extract,
         score_normalization=score_normalization,
         attr=attr,
         window=window,
