@@ -14,14 +14,23 @@ DEFAULT_CONFIG = dict(
 )
 
 
-@deprecated_factory("score", "eds.score", default_config=DEFAULT_CONFIG)
-@Language.factory("eds.score", default_config=DEFAULT_CONFIG)
+@deprecated_factory(
+    "score",
+    "eds.score",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
+)
+@Language.factory(
+    "eds.score",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
+)
 def create_component(
     nlp: Language,
     name: str,
     score_name: str,
     regex: List[str],
-    after_extract: str,
+    value_extract: str,
     score_normalization: Union[str, Callable[[Union[str, None]], Any]],
     attr: str,
     window: int,
@@ -32,7 +41,7 @@ def create_component(
         nlp,
         score_name=score_name,
         regex=regex,
-        after_extract=after_extract,
+        value_extract=value_extract,
         score_normalization=score_normalization,
         attr=attr,
         flags=flags,
