@@ -8,22 +8,31 @@ from edsnlp.utils.deprecation import deprecated_factory
 
 DEFAULT_CONFIG = dict(
     regex=patterns.regex,
-    after_extract=patterns.after_extract,
+    value_extract=patterns.value_extract,
     score_normalization=patterns.score_normalization_str,
     attr="NORM",
     window=10,
     ignore_excluded=False,
-    flags=re.S,
+    flags=0,
 )
 
 
-@deprecated_factory("SOFA", "eds.SOFA", default_config=DEFAULT_CONFIG)
-@Language.factory("eds.SOFA", default_config=DEFAULT_CONFIG)
+@deprecated_factory(
+    "SOFA",
+    "eds.SOFA",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
+)
+@Language.factory(
+    "eds.SOFA",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
+)
 def create_component(
     nlp: Language,
     name: str,
     regex: List[str],
-    after_extract: List[Dict[str, str]],
+    value_extract: List[Dict[str, str]],
     score_normalization: Union[str, Callable[[Union[str, None]], Any]],
     attr: str,
     window: int,
@@ -34,7 +43,7 @@ def create_component(
         nlp,
         score_name=name,
         regex=regex,
-        after_extract=after_extract,
+        value_extract=value_extract,
         score_normalization=score_normalization,
         attr=attr,
         window=window,
