@@ -6,11 +6,15 @@ from .tnm import TNM
 
 DEFAULT_CONFIG = dict(
     pattern=None,
-    attr="LOWER",
+    attr="TEXT",
 )
 
 
-@Language.factory("eds.TNM", default_config=DEFAULT_CONFIG)
+@Language.factory(
+    "eds.TNM",
+    default_config=DEFAULT_CONFIG,
+    assigns=["doc.ents", "doc.spans"],
+)
 def create_component(
     nlp: Language,
     name: str,
