@@ -19,8 +19,17 @@ DEFAULT_CONFIG = dict(
 )
 
 
-@deprecated_factory("hypothesis", "eds.hypothesis", default_config=DEFAULT_CONFIG)
-@Language.factory("eds.hypothesis", default_config=DEFAULT_CONFIG)
+@deprecated_factory(
+    "hypothesis",
+    "eds.hypothesis",
+    default_config=DEFAULT_CONFIG,
+    assigns=["span._.hypothesis"],
+)
+@Language.factory(
+    "eds.hypothesis",
+    default_config=DEFAULT_CONFIG,
+    assigns=["span._.hypothesis"],
+)
 def create_component(
     nlp: Language,
     name: str,
