@@ -1,6 +1,7 @@
-from typing import Any, Dict, List, Union
+from typing import Any, Callable, Dict, List, Optional, Union
 
 from spacy import Language
+from spacy.tokens import Doc
 
 from .helpers import DataFrameModules, DataFrames, get_module
 from .parallel import pipe as parallel_pipe
@@ -13,7 +14,8 @@ def pipe(
     nlp: Language,
     n_jobs: int = -2,
     context: List[str] = [],
-    additional_spans: Union[List[str], str] = "discarded",
+    results_extractor: Optional[Callable[[Doc], List[Dict[str, Any]]]] = None,
+    additional_spans: Union[List[str], str] = [],
     extensions: ExtensionSchema = [],
     **kwargs: Dict[str, Any],
 ) -> DataFrames:
@@ -37,8 +39,8 @@ def pipe(
 
         - `n_jobs=1` corresponds to `simple_pipe`
         - `n_jobs>1` corresponds to `parallel_pipe` with `n_jobs` parallel workers
-        - `n_jobs=-1` corresponds to `parallel_pipe` with maximun number of workers
-        - `n_jobs=-2` corresponds to `parallel_pipe` with maximun number of workers -1
+        - `n_jobs=-1` corresponds to `parallel_pipe` with maximum number of workers
+        - `n_jobs=-2` corresponds to `parallel_pipe` with maximum number of workers -1
     additional_spans : Union[List[str], str], by default "discarded"
         A name (or list of names) of SpanGroup on which to apply the pipe too:
         SpanGroup are available as `doc.spans[spangroup_name]` and can be generated
@@ -59,12 +61,16 @@ def pipe(
     module = get_module(note)
 
     if module == DataFrameModules.PANDAS:
+
+        kwargs.pop("dtypes", None)
+
         if n_jobs == 1:
 
             return simple_pipe(
                 note=note,
                 nlp=nlp,
                 context=context,
+                results_extractor=results_extractor,
                 additional_spans=additional_spans,
                 extensions=extensions,
                 **kwargs,
@@ -76,28 +82,47 @@ def pipe(
                 note=note,
                 nlp=nlp,
                 context=context,
+                results_extractor=results_extractor,
                 additional_spans=additional_spans,
                 extensions=extensions,
                 n_jobs=n_jobs,
                 **kwargs,
             )
 
-    if extensions and type(extensions) != dict:
-        raise ValueError(
-            """
-            When using Spark or Koalas, you should provide extension names
-            along with the extension type (as a dictionnary):
-            `d[extension_name] = extension_type`
-            """  # noqa W291
-        )
+    if type(extensions) != dict:
+        if extensions:
+            raise ValueError(
+                """
+                When using Spark or Koalas, you should provide extension names
+                along with the extension type (as a dictionnary):
+                `d[extension_name] = extension_type`
+                """  # noqa W291
+            )
+        else:
+            extensions = {}
 
+    from .distributed import custom_pipe
     from .distributed import pipe as distributed_pipe
 
-    return distributed_pipe(
-        note=note,
-        nlp=nlp,
-        context=context,
-        additional_spans=additional_spans,
-        extensions=extensions,
-        **kwargs,
-    )
+    if results_extractor is None:
+
+        return distributed_pipe(
+            note=note,
+            nlp=nlp,
+            context=context,
+            additional_spans=additional_spans,
+            extensions=extensions,
+            **kwargs,
+        )
+    else:
+
+        dtypes = kwargs.pop("dtypes")
+
+        return custom_pipe(
+            note=note,
+            nlp=nlp,
+            context=context,
+            results_extractor=results_extractor,
+            dtypes=dtypes,
+            **kwargs,
+        )
