@@ -1,3 +1,6 @@
+import gzip
+import json
+from functools import lru_cache
 from typing import List, Optional
 
 import pandas as pd
@@ -38,3 +41,17 @@ def get_verbs(
         assert len(verbs) == selected_verbs.verb.nunique(), "Some verbs are missing !"
 
     return selected_verbs
+
+
+@lru_cache()
+def get_adicap_dict():
+    """
+    Returns
+    -------
+    Dict
+    """
+
+    with gzip.open(BASE_DIR / "resources" / "adicap.json.gz", "r") as fin:
+        decode_dict = json.loads(fin.read().decode("utf-8"))
+
+    return decode_dict
